v0.3.4 (August 02, 2022)
========================
  * Add Python 3.10 to CI workflows (#122)
  * Add fit, fit_transform, transform, predict, and score methods (#119)
  * NF: Allow passing an AFQDataset object as input. (#113)
  * Add 1D cnn models and data augmentation (#112)
  *  (#107)
  * Remove groupyr ref from user guide (#110)
  * Remove groupyr references from contribution guide (#109)

